%define up_name		Aegisub

%define subrel		1
%define rel		9

%define date		20191006

%if %{date}
%define release		%mkrel 14.git%{date}.%{rel}
%define tarballver	%{commit}
%define tarballdir	%{commit}
%define tarballgit	+git%{date}
%define commit		6f546951b4f004da16ce19ba638bf3eedefb9f31
%else
%define release		%mkrel %{rel}
%define tarballver	%{version}
%define tarballdir	v%{version}
%endif

Name:		aegisub
Version:	3.2.2
Release:	%{release}
Summary:	Advanced Subtitle Editor
Group:		Video/Editors and Converters
License:	BSD
URL:		http://www.aegisub.org/
Source0:	https://github.com/Aegisub/Aegisub/archive/%{tarballdir}/%{up_name}-%{version}%{?tarballgit}.tar.gz
### Only needed if using a git snapshot (git_version.h)
Source1:	git_version.h
Patch1:		aegisub-fix-makefile-for-make4.3.patch
# Originally from Gentoo, modified to apply to git
Patch50:	aegisub-3.2.2+git20180305-fix-system-luajit-build.patch
# From https://github.com/Aegisub/Aegisub/pull/134
Patch100:       0001-Fix-deprecated-calls-to-wxSTC.patch
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(ffms2)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(fontconfig)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(hunspell)
BuildRequires:	pkgconfig(icu-io)
BuildRequires:	pkgconfig(libass)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libpulse)
BuildRequires:	pkgconfig(luajit)
BuildRequires:	pkgconfig(portaudio-2.0)
BuildRequires:	pkgconfig(uchardet)
BuildRequires:	boost-devel
BuildRequires:	gettext-devel
BuildRequires:	intltool
BuildRequires:	luajit >= 2.1.0-0.beta3.3
BuildRequires:	wxgtk-devel

%description
Aegisub is an advanced subtitle editor that assists in the creation of
subtitles, translations, and complex overlays using audio or video. Developed
by enthusiasts it builds on work-flows created and perfected through
professional, hobby, and everyday use.


%prep
%setup -q -n %{up_name}-%{tarballver}
%autopatch -p1

### Only needed if using a git snapshot (git_version.h)
cp %{SOURCE1} build/

### Build with system luajit
rm -rf vendor/luajit

### Fix build with luajit >= 2.1.0
sed -i -e 's,luaL_reg ,luaL_Reg ,g' vendor/luabins/src/luabins.c libaegisub/lua/modules/lpeg.c

%build
NOCONFIGURE=1 ./autogen.sh
export CXXFLAGS="%{optflags} -Wno-deprecated-declarations"
%configure \
		--without-oss \
		--without-openal \
		--with-system-luajit \
		--with-player-audio=PulseAudio \
		--with-wx-config=wx-config \
		--with-build-credit=%{_vendor} \
		--with-boost-libdir=%{_libdir} \
		--disable-update-checker
%make_build

%install
%make_install

%find_lang %{name}

%files -f %{name}.lang
%doc automation/demos/ automation/v4-docs/
%license LICENCE
%{_bindir}/%{name}*
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
%{_metainfodir}/%{name}.appdata.xml


%changelog
* Mon Apr 05 2021 wally <wally> 3.2.2-14.git20191006.9.1.mga8
+ Revision: 1713517
- add patch to fix deprecated calls to wxSTC (mga#28713)

* Fri Jan 01 2021 wally <wally> 3.2.2-14.git20191006.9.mga8
+ Revision: 1667685
- rebuild for wxgtk pre 3.1.5 snapshot

* Thu Dec 31 2020 wally <wally> 3.2.2-14.git20191006.8.mga8
+ Revision: 1666732
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 3.2.2-14.git20191006.7.mga8
+ Revision: 1661974
- rebuild for boost 1.74.0

* Mon Nov 30 2020 luigiwalser <luigiwalser> 3.2.2-14.git20191006.6.mga8
+ Revision: 1650875
- rebuild for icu

* Sun Aug 16 2020 wally <wally> 3.2.2-14.git20191006.5.mga8
+ Revision: 1614322
- rebuild for new wxgtk 3.1.4

* Wed Jul 01 2020 wally <wally> 3.2.2-14.git20191006.4.mga8
+ Revision: 1601012
- rebuild for icu 67.1

* Sun May 03 2020 wally <wally> 3.2.2-14.git20191006.3.mga8
+ Revision: 1578028
- rebuild for boost 1.73.0

* Sat Apr 04 2020 wally <wally> 3.2.2-14.git20191006.2.mga8
+ Revision: 1564447
- rebuild for new icu 66.1

* Sat Apr 04 2020 wally <wally> 3.2.2-14.git20191006.1.mga8
+ Revision: 1564254
- add patch to fix buidl with make >= 4.3
- rebuild for boost 1.72.0
- replace deprecated %%configure2_5x
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ daviddavid <daviddavid>
- new snapshot: 3.2.2-git20191006
  * commit: 6f546951b4f004da16ce19ba638bf3eedefb9f31

* Tue Nov 12 2019 wally <wally> 3.2.2-14.git20180730.9.mga8
+ Revision: 1459448
- rebuild for wxgtk 3.1.3

* Sat Oct 05 2019 daviddavid <daviddavid> 3.2.2-14.git20180730.8.mga8
+ Revision: 1449471
- rebuild for new icu 65.1

* Mon Jul 08 2019 wally <wally> 3.2.2-14.git20180730.7.mga8
+ Revision: 1419517
- rebuild for wxgtk 3.1.2 with 2.8 compatibility

* Sun Jul 07 2019 wally <wally> 3.2.2-14.git20180730.6.mga8
+ Revision: 1419286
- rebuild with gtk3 enabled wxgtk 3.1.2

* Sat Dec 29 2018 luigiwalser <luigiwalser> 3.2.2-14.git20180730.5.mga7
+ Revision: 1346084
- rebuild for icu

* Fri Nov 23 2018 daviddavid <daviddavid> 3.2.2-14.git20180730.4.mga7
+ Revision: 1333467
- rebuild for new hunspell 1.7.0

* Tue Oct 16 2018 wally <wally> 3.2.2-14.git20180730.3.mga7
+ Revision: 1321005
- rebuild for new boost 1.68.0

* Thu Oct 04 2018 daviddavid <daviddavid> 3.2.2-14.git20180730.2.mga7
+ Revision: 1317753
- Mageia 7 Mass Rebuild

* Wed Aug 22 2018 daviddavid <daviddavid> 3.2.2-14.git20180730.1.mga7
+ Revision: 1253452
- new snapshot: 3.2.2-git20180730
  * commit: 83736b4866ecae9b7c42a2c6cb576e376a8d04e2
- rebuild for new icu

* Fri Jul 13 2018 wally <wally> 3.2.2-14.git20180305.3.mga7
+ Revision: 1243420
- build with system luajit (modified patch from Gentoo)

* Mon Apr 02 2018 daviddavid <daviddavid> 3.2.2-14.git20180305.2.mga7
+ Revision: 1214589
- new snapshot: 3.2.2-git20180305
  * commit: f6a2ac08a63f37c1cb3e7315144411f7d5aa5403
- switch to freetype2

* Fri Dec 29 2017 wally <wally> 3.2.2-14.git20170522.6.mga7
+ Revision: 1186961
- rebuild for new icu

* Mon Dec 25 2017 wally <wally> 3.2.2-14.git20170522.5.mga7
+ Revision: 1184648
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 3.2.2-14.git20170522.4.mga7
+ Revision: 1178109
- rebuild for boost 1.65

* Sat Sep 16 2017 tv <tv> 3.2.2-14.git20170522.3.mga7
+ Revision: 1154669
- rebuild with latest boost

* Sun Aug 06 2017 daviddavid <daviddavid> 3.2.2-14.git20170522.2.mga7
+ Revision: 1137559
- new snapshot: 3.2.2-git20170522
  * commit: 8d3ad9ff68808b14ea0b29f6efffd1ba5089319a
- rebuild against new hunspell 1.6.1

* Sat Jun 03 2017 akien <akien> 3.2.2-14.git20160730.7.mga6
+ Revision: 1106080
- Rebuild for wxgtk 3.0.3.1

* Wed Mar 29 2017 neoclust <neoclust> 3.2.2-14.git20160730.6.mga6
+ Revision: 1095174
- Try to build on armv5

* Thu Mar 16 2017 mrambo3501 <mrambo3501> 3.2.2-14.git20160730.5.mga6
+ Revision: 1093083
- Rebuild for icu-58.2

* Tue Jan 10 2017 luigiwalser <luigiwalser> 3.2.2-14.git20160730.4.mga6
+ Revision: 1080915
- rebuild for libass

* Tue Oct 25 2016 daviddavid <daviddavid> 3.2.2-14.git20160730.3.mga6
+ Revision: 1063489
- new snapshot: 3.2.2-git20160730
  * commit: 10422265311494278928dcd2a7a084e4811bcf0d

* Thu Jun 02 2016 daviddavid <daviddavid> 3.2.2-14.git20160518.2.mga6
+ Revision: 1019800
- rebuild for wxgtk3.0 built with GTK2

* Fri May 20 2016 daviddavid <daviddavid> 3.2.2-14.git20160518.1.mga6
+ Revision: 1017170
- new snapshot: 3.2.2-git20160518
  * commit: b118fe7e7a5c37540e2f0aa75af105e272bad234
- add an upstream patch to fix missing AM_GNU_GETTEXT_VERSION macro
- add BR pkgconfig(uchardet)

* Fri May 13 2016 shlomif <shlomif> 3.2.2-13.mga6
+ Revision: 1014872
- Rebuild for new ICU

* Thu Apr 21 2016 tv <tv> 3.2.2-12.mga6
+ Revision: 1004213
- rebuid for libhunspell 1.4

* Thu Jan 14 2016 pterjan <pterjan> 3.2.2-11.mga6
+ Revision: 922915
- Disable on ARMv5

* Fri Jan 01 2016 luigiwalser <luigiwalser> 3.2.2-10.mga6
+ Revision: 917816
- rebuild for icu

* Fri Dec 25 2015 daviddavid <daviddavid> 3.2.2-9.mga6
+ Revision: 914607
- rebuild for new boost 1.60.0

* Fri Sep 25 2015 daviddavid <daviddavid> 3.2.2-8.mga6
+ Revision: 883443
- rebuild for new boost 1.59.0
- introduce license macro

* Sun Sep 06 2015 daviddavid <daviddavid> 3.2.2-7.mga6
+ Revision: 873233
- rebuild with gcc 5.2.1

* Fri Aug 14 2015 ycantin <ycantin> 3.2.2-6.mga6
+ Revision: 864689
- rebuild for new wxgtk built with wxRE_ADVANCED

* Fri Jul 31 2015 daviddavid <daviddavid> 3.2.2-5.mga6
+ Revision: 859482
- rebuild for new boost-1.58.0

* Sat Jul 25 2015 daviddavid <daviddavid> 3.2.2-4.mga6
+ Revision: 857246
- rebuild for icu 55

* Wed Jul 22 2015 daviddavid <daviddavid> 3.2.2-3.mga6
+ Revision: 856205
- rebuild for new wxgtk built with gtk3

* Sat Jun 20 2015 daviddavid <daviddavid> 3.2.2-2.mga6
+ Revision: 836933
- rebuild for new ffms2

* Thu Dec 11 2014 daviddavid <daviddavid> 3.2.2-1.mga5
+ Revision: 802755
- new version: 3.2.2

* Sun Oct 19 2014 daviddavid <daviddavid> 3.2.1-1.mga5
+ Revision: 791892
- new version: 3.2.1

* Wed Oct 15 2014 umeabot <umeabot> 3.2.0-4.mga5
+ Revision: 750322
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.2.0-3.mga5
+ Revision: 677705
- Mageia 5 Mass Rebuild

* Wed Aug 20 2014 daviddavid <daviddavid> 3.2.0-2.mga5
+ Revision: 666026
- bump release

* Mon Aug 04 2014 daviddavid <daviddavid> 3.2.0-1.mga5
+ Revision: 659670
- switch to latest version of lua5.2 as it is now supported
- remove unneeded FIXME for correct assignment of rights of desktop file as it is now fixed upstream
- new version: 3.2.0

* Fri Apr 11 2014 daviddavid <daviddavid> 3.1.3-1.mga5
+ Revision: 613500
- remove unneeded BR
- new version: 3.1.3

* Mon Apr 07 2014 daviddavid <daviddavid> 3.1.2-1.mga5
+ Revision: 612680
- imported package aegisub

